<?php

$newproject_text = array (

'createnewproject'	=>	'Utwórz nowy projekt',
'projecttitle'		=>	'Nazwa projektu',
'themestyle'		=>	'Styl',
'projectprefs'		=>	'Ustawienia projektu',
'defaultproject'	=>	'Projekt domyślny',
'projectlists'		=>	'Lista projektów',
'addnewproject'		=>	'Dodaj projekt',
'showlogo'		=>	'Pokazuj logo',
'intromessage'		=>	'Tekst wprowadzający',
'htmlallowed'		=>	'Zezwalaj na kod HTML',
'createproject'		=>	'Utwórz projekt',
'noone'			=>	'Nikt',
'defaultcatowner'	=>	'Domyślny właściciel kategorii',
'createthisproject'	=>	'Utwórz projekt',
'nopermission'		=>	'Nie masz uprawnień do używania tej strony',

// Added in version 0.9.6
'inlineimages'		=>	'Wyświetl załączniki w treści strony',

// Added in version 0.9.7
'othersview'		=>	'Zezwalaj wszystkim na przeglądanie tego projektu',
'allowanonopentask'     =>      'Zezwalaj na anonimowe dodawanie zgłoszeń',

);
// vim:fenc=utf-8:enc=utf-8:nowrap
?>
